@@ -4,14 +4,12 @@ BEGIN {
 	die "Encode::KR not supported on EBCDIC\n";
     }
 }
-our $VERSION = do { my @r = (q$Revision: 0.99 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 1.0 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 use Encode;
 use XSLoader;
 XSLoader::load('Encode::KR',$VERSION);
 
-use Encode::KR::2022_KR;
-
 1;
 __END__
 =head1 NAME
@@ -32,18 +30,26 @@ are as follows.
 
   Canonical   Alias		Description
   --------------------------------------------------------------------
-  euc-kr      /euc.*kr$/i	EUC (Extended Unix Character)
-	      /kr.*euc/i
+  euc-kr      /\beuc.*kr$/i	EUC (Extended Unix Character)
+	      /\bkr.*euc$/i
   ksc5601			Korean standard code set
-  cp949				Code Page 949 
-				(EUC-KR + Unified Hangul Code)
+  cp949				Code Page 949 (EUC-KR + 8,822 
+                                (additional Hangul syllables)
+  johab       JOHAB             A supplementary encoding defined in 
+                                Annex 3 of KS X 1001:1998
+  iso-2022-kr                   iso-2022-kr                  [RFC1557]
   --------------------------------------------------------------------
   
 To find how to use this module in detail, see L<Encode>.
 
 =head1 BUGS
 
-The C<Johab> (two-byte combination code) encoding is not supported.
+When you see C<charset=ks_c_5601-1987> on mails and web pages, they really
+mean "cp949" encodings.  To fix that, the following aliases are set;
+
+  qr/(?:x-)?uhc$/i         => '"cp949"'
+  qr/(?:x-)?windows-949$/i => '"cp949"'
+  qr/ks_c_5601-1987$/i     => '"cp949"'
 
 ASCII part (0x00-0x7f) is preserved for all encodings, even though it
 conflicts with mappings by the Unicode Consortium.  See
